#

##

    	nature

    	structure

    		{
    			"kind": "food",

    			"identity": {
    				"name": "",
    				"UPC": "",
    				"DSLD ID": "",
    				"FDC ID": ""
    			},

    			"brand": {
    				"name": ""
    			},

    			"measures": ./measures/measures.S.HTML
    				# packages sums

    			"measured ingredients":

    			"unmeasured ingredients":

    			#
    			#	lands are 1+ treasures
    			#
    			"essential nutrients":
    				# land

    			"cautionary ingredients":
    				# land
    				# poisoinous ingredients
    				# potentially harmful
    				# dangerous ingredients
    				# unhealthy ingredients

    		}